<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

add_action( 'widgets_init', function(){
     register_widget( 'NNRobots_Content_Fire_Widget' );
});

if ( !class_exists('NNRobots_Content_Fire_Widget') ) :

/**
 * Adds NNRobots_Popular_Posts_Widget widget.
 */
class NNRobots_Content_Fire_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'nnr-content-fire', // Base ID
			__( '99 Robots Content Fire', NNRobots_Content_Fire::$text_domain ), // Name
			array( 'description' => __( 'Displays an Content Fire', NNRobots_Content_Fire::$text_domain ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . "/admin/model/db.php");
		include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . "/core/functions.php");

		global $wpdb;

		// Get all Content Fires

		$content_fire = $wpdb->get_results(
			$wpdb->prepare("SELECT * FROM `" . NNRobots_Content_Fire_DB::getTableName() . "` WHERE `id` = %d", $instance['content_fire_id'])
		, 'ARRAY_A');

		$content_fire = $content_fire[0];

		$content_fire_args         = NNRobots_Content_Fire_Functions::mb_unserialize($content_fire['args']);
    	$content_fire_template     = NNRobots_Content_Fire_Functions::mb_unserialize($content_fire['template']);
		$content_fire_trigger      = NNRobots_Content_Fire_Functions::mb_unserialize($content_fire['trigger']);
		$content_fire_news_letter  = NNRobots_Content_Fire_Functions::mb_unserialize($content_fire['news_letter']);

		// Check that conditions are true

		if (NNRobots_Content_Fire_Functions::check_conditions($content_fire['id'], $content_fire_template, $content_fire_args, $content_fire_trigger['args'])) {
			echo $args['before_widget'];
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
			}
    		echo NNRobots_Content_Fire_Functions::generate_code($content_fire, $content_fire_news_letter, true);
    		echo $args['after_widget'];
		}

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . "/admin/model/db.php");
		include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . "/core/functions.php");

		global $wpdb;

		// Get all Content Fires

		$content_fires = $wpdb->get_results("SELECT * FROM `" . NNRobots_Content_Fire_DB::getTableName() . "`");
		$widget_content_fires = array();

		foreach ($content_fires as $content_fire) {

			$args = NNRobots_Content_Fire_Functions::mb_unserialize($content_fire->args);

			if ($args['placement']['type'] == 'none') {
				$widget_content_fires[] = $content_fire;
			}
		}

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo (isset($instance['title']) ? $instance['title'] : ''); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'content-fire-id' ); ?>"><?php _e( 'Content Fire:' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'content-fire-id' ); ?>" name="<?php echo $this->get_field_name( 'content-fire-id' ); ?>">

				<?php foreach ($widget_content_fires as $content_fire) {?>
					<option value="<?php echo $content_fire->id; ?>" <?php selected($content_fire->id, $instance['content_fire_id'], true); ?>><?php echo $content_fire->name; ?></option>
				<?php } ?>

			</select>
		</p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['content_fire_id'] = ( ! empty( $new_instance['content-fire-id'] ) ) ? strip_tags( $new_instance['content-fire-id'] ) : '';

		return $instance;
	}

}

endif;